#!/usr/bin/gnuplot

# Miroslav Broz (miroslav.broz@email.cz), Jul 26th 2002

set colors classic
#set term x11

set tit ""
set xl "diameter {/Helvetica-Oblique D} / km"
set yl "number of asteroids {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.25,0

set xr [100.e-9:1000]
miny=0.8
maxy=2e25
set yr [miny:maxy]
set logscale xy
set xtics 10
set mxtics 10
set ytics 10
set mytics 10
set key samplen 1.0 spacing 1.5
set xtics format "10^{%T}"
set ytics format "10^{%T}"

set arrow from 1,graph 0 rto 0,graph 1 nohead lt 0
set arrow from 0.001,graph 0 rto 0,graph 1 nohead lt 0
set arrow from 100.e-9,graph 0 rto 0,graph 1 nohead lt 0

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family2(x) = (10**3.40784296e+00) * x**(-2.80536346e+00)  # Massalia
f_family3(x) = (10**3.40784296e+00) * x**(-2.70536346e+00)  # Massalia
f_family4(x) = (10**3.40784296e+00) * x**(-2.90536346e+00)  # Massalia
#f_family2(x) = (0.5*10**3.40784296e+00) * x**(-2.80536346e+00)  # Massalia, one half of bodies!
#f_family4(x) = (10**3.40784296e+00) * x**(-2.88          )  # Massalia, hitting IRAS 1.4-deg band!

tmp=0.3; set label sprintf("   %.1f   ", -2.80536346e+00) at tmp,f_family2(tmp) font "Helvetica,14" right

set arrow from 1.0e-3,10e10 to 1.0e-3,30e10 heads lc 'black' front size graph 0.01,90 fixed

p \
  "<echo 100.e-9 9.7e24" w p pt 1 ps 3 lw 8 lc '#0066ff' t "zodiacal cloud",\
  "<echo 100.e-9 4.0e23" w p pt 1 ps 3 lw 8 lc '#00ffcc' t "IRAS 1.4{/Symbol\260} band",\
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../../boulder/33_MB_Karin/*[0-9]*/tmp/0006.out | ./hc.awk" u 1:2 t "evolved MB"    w l lw 2 lc '#0066ff',\
  "../../boulder/dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) not w p pt 7 lc '#ffffff',\
  "../../boulder/dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) t "{/=14 Bottke etal. (2015)}" w p pt 7 lc '#bbbbff',\
  "<awk '($1>-1) && ($1<0.2)' ../../boulder/dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) not w p pt 7 lc '#ffffff',\
  "<awk '($1>-1) && ($1<0.2)' ../../boulder/dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) not w p pt 7 lc '#bbbbff',\
  f_family2(x) not lc '#00ff66' dt 2,\
  f_family0(x) not lc 'gray'    dt 2,\
  "../../main_belt_families_2021Jun/20_Massalia/size_distribution/family.dat_hc"       w l lc '#00ff66'  lw 3 t "Massalia (L)",\

pa -1

set term postscript eps enh color solid "Helvetica" 18
set out "Massalia_DUST.eps"
set size 0.625*1.5,0.9*1.5
rep

system("eps2png Massalia_DUST.eps")

q

  f_family3(x) not lc '#00ff66' dt 2,\
  f_family4(x) not lc '#00ff66' dt 2,\

  "<echo 100.e-9 2.7e24" w p pt 1 ps 3 lw 8 lc '#0000cc' t "IRAS 8{/Symbol\260} band",\
  "<echo 100.e-9 1.3e24" w p pt 1 ps 3 lw 8 lc '#cc00ff' t "IRAS 2.1{/Symbol\260} band",\

